%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

%global __provides_exclude perl\\(.*Texinfo.*\\)
%global __requires_exclude perl\\(.*Texinfo.*\\)

Name:		texinfo
Version:	7.1
Release:	%mkrel 1
Summary:	Tools needed to create Texinfo format documentation files
License:	GPLv3
Group:		Publishing
URL:		https://www.gnu.org/software/texinfo/
Source0:	ftp://ftp.gnu.org/gnu/texinfo/%{name}-%{version}.tar.xz
Source1:	ftp://ftp.gnu.org/gnu/texinfo/%{name}-%{version}.tar.xz.sig
Source2:	fix-info-dir
Source3:	info-dir
Patch107:	texinfo-6.0-vikeys-segfault-fix.patch
# Patch0: we need to fix template fix-info-dir generates
Patch0:		info-6.5-sync-fix-info-dir.patch
# Patch1: rhbz#1592433, bug in fix-info-dir --delete
Patch1:		texinfo-6.5-fix-info-dir.patch
# Patch2: fixes issues detected by static analysis
Patch2:		texinfo-6.5-covscan-fixes.patch 
Patch10:	texinfo-7.1-disable-failing-info-test.patch

# Mageia patches
Patch51:	0001-fix-info-dir-add-xz-support.patch

# (anssi 01/2008) for make check:
%if %bootstrap == 0
BuildRequires:	tetex
BuildRequires:	tetex-latex
BuildRequires:	xmltex
%endif
BuildRequires:	ncurses-devel
BuildRequires:	help2man
BuildRequires:	perl(Locale::Messages)
BuildRequires:	perl(Unicode::EastAsianWidth)
BuildRequires:	perl(Text::Unidecode)
Provides:	makeinfo = %{version}-%{release}

%description
Texinfo is a documentation system that can produce both online information
and printed output from a single source file.  Normally, you'd have to
write two separate documents: one for online help or other online
information and the other for a typeset manual or other printed work.
Using Texinfo, you only need to write one source document.  Then when the
work needs revision, you only have to revise one source document.  The GNU
Project uses the Texinfo file format for most of its documentation.

Install texinfo if you want a documentation system for producing both
online and print documentation from the same source file and/or if you are
going to write documentation for the GNU Project.

%package -n info
Summary:	A stand-alone TTY-based reader for GNU texinfo documentation
Group:		System/Base
Conflicts:	info-install < 6.5-7
Requires:	info-install

%description -n	info
The GNU project uses the texinfo file format for much of its
documentation. The info package provides a standalone TTY-based browser
program for viewing texinfo files.

You should install info, because GNU's texinfo documentation is a valuable
source of information about the software on your system.

%package -n info-install
Summary:	Program to update the GNU texinfo documentation main page
Group:		System/Base
Requires(pre):	makedev
Requires:	xz
# explicit file provides
Provides:	/sbin/install-info

%description -n	info-install
The GNU project uses the texinfo file format for much of its
documentation. The info package provides a standalone TTY-based browser
program for viewing texinfo files.

%package tex
Summary:	Tools for formatting Texinfo documentation files using TeX
Group:	Publishing
Requires:	texinfo = %{version}-%{release}
Requires:	texmf-data
Requires:	texlive
Requires(post):	texlive
Requires(postun):	texlive

%description tex
Texinfo is a documentation system that can produce both online
information and printed output from a single source file. The GNU
Project uses the Texinfo file format for most of its documentation.

The texinfo-tex package provides tools to format Texinfo documents
for printing using TeX.

%prep
%setup -q
mkdir contrib
install -Dpm0755 -t contrib %{SOURCE2}
%autopatch -p1

%build
%configure \
	--with-external-Text-Unidecode \
	--with-external-libintl-perl \
	--with-external-Unicode-EastAsianWidth \
	--disable-perl-xs \
	--disable-rpath

%make_build

%install
%make_install

install -m644 %{SOURCE3} -D %{buildroot}%{_sysconfdir}/info-dir
rm -rf %{buildroot}%{_infodir}/dir
ln -s %{_sysconfdir}/info-dir %{buildroot}%{_infodir}/dir
mkdir -p %{buildroot}/sbin
mv %{buildroot}%{_bindir}/install-info %{buildroot}/sbin/install-info
mkdir -p %{buildroot}%{_sysconfdir}/X11/wmconfig

# Doc install for the tex subpackage (from Fedora)
mkdir -p %{buildroot}%{_datadir}/texmf/tex/texinfo
install -p -m644 doc/texinfo.tex doc/txi-??.tex %{buildroot}%{_datadir}/texmf/tex/texinfo

find %{buildroot} -name "*.*a" -delete

install -Dpm0755 -t %{buildroot}%{_sbindir} contrib/fix-info-dir

%find_lang %{name}
%find_lang %{name}_document

%check
export ALL_TESTS=yes
%make_build check

%transfiletriggerin -n info -- %{_infodir}
[ -f %{_infodir}/dir ] && create_arg="" || create_arg="--create"
%{_sbindir}/fix-info-dir $create_arg %{_infodir}/dir &>/dev/null ||:

%transfiletriggerpostun -n info -- %{_infodir}
[ -f %{_infodir}/dir ] && %{_sbindir}/fix-info-dir --delete %{_infodir}/dir &>/dev/null ||:

%files -f %{name}.lang -f %{name}_document.lang
%doc AUTHORS NEWS README TODO
%{_bindir}/makeinfo
%{_bindir}/texi2any
%{_infodir}/info-stnd.info*
%{_infodir}/texinfo*
%{_infodir}/texi2any_api.info*
%{_infodir}/texi2any_internals.info* 
%{_mandir}/man1/makeinfo.1*
%{_mandir}/man1/texi2any.1*
%{_mandir}/man5/texinfo.5*
%{_datadir}/texinfo

%files -n info
%{_bindir}/info
%{_mandir}/man1/info.1*
%{_mandir}/man5/info.5*

%files -n info-install
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/info-dir
%{_infodir}/dir
/sbin/install-info
%{_sbindir}/fix-info-dir
%{_mandir}/man1/install-info.1*

%files tex
%{_bindir}/texindex
%{_bindir}/texi2dvi
%{_bindir}/texi2pdf
%{_bindir}/pdftexi2dvi
%{_bindir}/pod2texi
%{_datadir}/texmf/tex/texinfo
%{_mandir}/man1/texindex.1*
%{_mandir}/man1/texi2dvi.1*
%{_mandir}/man1/texi2pdf.1*
%{_mandir}/man1/pod2texi.1*
%{_mandir}/man1/pdftexi2dvi.1*


%changelog
* Tue Dec 05 2023 daviddavid <daviddavid> 7.1-1.mga10
+ Revision: 2013459
- new version: 7.1

* Tue Mar 28 2023 luigiwalser <luigiwalser> 7.0.3-1.mga9
+ Revision: 1950526
- 7.0.3

* Thu Feb 23 2023 daviddavid <daviddavid> 7.0.2-2.mga9
+ Revision: 1945167
- fix possible use of an undefined value as an ARRAY reference in ParserNonXS.pm
  (causes FTBFS of a2ps)

* Mon Jan 23 2023 luigiwalser <luigiwalser> 7.0.2-1.mga9
+ Revision: 1935124
- 7.0.2

* Thu Dec 01 2022 luigiwalser <luigiwalser> 7.0.1-1.mga9
+ Revision: 1913798
- 7.0.1

* Fri Nov 18 2022 daviddavid <daviddavid> 7.0-1.mga9
+ Revision: 1908692
- new version: 7.0 (sync partially with fedora)

* Thu Mar 17 2022 umeabot <umeabot> 6.8-2.mga9
+ Revision: 1797224
- Mageia 9 Mass Rebuild

* Tue Aug 03 2021 luigiwalser <luigiwalser> 6.8-1.mga9
+ Revision: 1738729
- 6.8
- remove zlib patch
- update covscan fixes patch from fedora (and renumber patches)
- add patch from fedora to revert gnulib change that breaks build

* Sat Aug 15 2020 wally <wally> 6.7-3.mga8
+ Revision: 1614150
- add xz support to fix-info-dir script
- sync fix-info-dir patches with Fedora
- make info to require info-install for filetrigger scriptlets
- provide makeinfo
- drop old conflicts

* Tue Feb 18 2020 umeabot <umeabot> 6.7-2.mga8
+ Revision: 1541971
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Jan 03 2020 luigiwalser <luigiwalser> 6.7-1.mga8
+ Revision: 1475797
- 6.7
- sync patches with fedora

* Mon May 13 2019 luigiwalser <luigiwalser> 6.5-7.mga8
+ Revision: 1397531
- update URL

* Sun Jan 13 2019 wally <wally> 6.5-7.mga7
+ Revision: 1355850
- check that fix-info-dir exists before trying to run it in filetriggers
- don't exit with status 1 if /usr/share/info/dir doesn't exist when running filetriggers
- move info man pages to info pkg

* Tue Dec 25 2018 wally <wally> 6.5-6.mga7
+ Revision: 1344938
- fix requires and provides excludes

* Tue Dec 25 2018 wally <wally> 6.5-5.mga7
+ Revision: 1344937
- build with external perl modules
  - perl(Locale::Messages)
  - perl(Unicode::EastAsianWidth)
  - perl(Text::Unidecode)
- drop install-info build hack

* Sun Sep 02 2018 tv <tv> 6.5-4.mga7
+ Revision: 1256274
- implement transfiletrigger* for regenerating cache (mga#23482 related)
  make sure to not recreate cache from scratch
- make testsuite //
- Fix bug in fix-info-dir which prevented the future transfiletriggerpostun script
  from working properly.
- sync with other fixes from FC
- install fix-info-dir
- use %%autosetup
- drop unapplied patch 200 (doesn't apply anyway)
- Fix fail of test because of unescaped left brace with Perl 5.28 (rhbz#1590308)

* Sat Jun 16 2018 wally <wally> 6.5-3.mga7
+ Revision: 1237274
- change info-install's makedev req to pre-req to be available earlier

* Fri Jun 15 2018 wally <wally> 6.5-2.mga7
+ Revision: 1237134
- make info-install to require makedev to suppress missing /dev/null post scriptlet errors when installing chroot with dnf

* Wed Mar 14 2018 kekepower <kekepower> 6.5-1.mga7
+ Revision: 1209525
- Update to version 6.5
- Enable make test
- Removed old patches
- Use new make macros

* Mon May 09 2016 luigiwalser <luigiwalser> 6.1-1.mga6
+ Revision: 1011632
- 6.1
- sync patches with fedora

* Fri Jan 01 2016 luigiwalser <luigiwalser> 6.0-1.mga6
+ Revision: 917651
- 6.0
- rediff patch 107
- disable patch 200 for now (needs to be rewritten)
- resync patch 300 (zlib patch) from fedora
- add patch 301 (disable failing test) from fedora
- infokey command is no more

* Sun Jul 05 2015 sander85 <sander85> 5.2-8.mga6
+ Revision: 851072
- Add more req/prov excludes

* Wed Oct 15 2014 umeabot <umeabot> 5.2-7.mga5
+ Revision: 750759
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Fri Feb 14 2014 oden <oden> 5.2-5.mga5
+ Revision: 591062
- fix deps

* Thu Feb 13 2014 jquelin <jquelin> 5.2-4.mga5
+ Revision: 590693
- do not provide perl(xxx) in rpm (not a perl module to be used outside texinfo)

* Mon Oct 21 2013 umeabot <umeabot> 5.2-3.mga4
+ Revision: 538228
- Mageia 4 Mass Rebuild

* Sun Sep 29 2013 fwang <fwang> 5.2-2.mga4
+ Revision: 489028
- add conflicts to ease upgrade

* Fri Sep 27 2013 fwang <fwang> 5.2-1.mga4
+ Revision: 487507
- new version 5.2

* Fri Aug 02 2013 tmb <tmb> 5.1-5.mga4
+ Revision: 462647
- update conflicts for makefile and texi2any file move

* Fri Aug 02 2013 malo <malo> 5.1-4.mga4
+ Revision: 462491
- move texi2any and makeinfo back to the main package

* Thu Aug 01 2013 malo <malo> 5.1-3.mga4
+ Revision: 462387
- fix makeinfo man page

* Sun Jul 28 2013 tmb <tmb> 5.1-2.mga4
+ Revision: 459649
- disable testsuite as its incompatible with perl-5.18
- makeinfo symlink belongs in -tex subpackage as it points to texi2any

* Thu Jul 25 2013 malo <malo> 5.1-1.mga4
+ Revision: 458095
- add BuildRequires xmltex for one test to pass
- update to 5.1 (William Murphy)
- update patch list

* Fri May 17 2013 tmb <tmb> 4.13a-10.mga3
+ Revision: 413508
- fix dpkg conflict

* Fri May 17 2013 malo <malo> 4.13a-9.mga3
+ Revision: 413491
- add conflict with dpkg to fix upgrade (mga#10132

* Wed Jan 23 2013 pterjan <pterjan> 4.13a-8.mga3
+ Revision: 391614
- Real fix for the file dependency, it was actually manually added

* Mon Jan 21 2013 pterjan <pterjan> 4.13a-7.mga3
+ Revision: 390631
- BuildRequires texlive to avoid file dependency on /usr/bin/texconfig-sys

* Mon Jan 21 2013 malo <malo> 4.13a-6.mga3
+ Revision: 390457
- fix file list
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jun 09 2012 malo <malo> 4.13a-5.mga3
+ Revision: 258678
- adding conflict for upgrade

* Sat Jun 09 2012 malo <malo> 4.13a-4.mga3
+ Revision: 258671
- spec clean-up
- fix license to GPLv3
- split texinfo to create a texinfo-tex subpackage not to require texlive by
  default (mga# 5940)
- add upstream/Gentoo patch to fix make test (accent encoding)

* Mon Aug 15 2011 wally <wally> 4.13a-3.mga2
+ Revision: 133434
- add chunks (from Gentoo) to xz patch to handle install-info --remove
  correctly with xz compressed files

* Tue Jan 11 2011 ahmad <ahmad> 4.13a-2.mga1
+ Revision: 6305
- imported package texinfo


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 4.13a-2mdv2011.0
+ Revision: 607992
- rebuild

* Sun Mar 21 2010 Funda Wang <fwang@mandriva.org> 4.13a-1mdv2010.1
+ Revision: 526011
- New version 4.13a

* Tue Feb 16 2010 Emmanuel Andry <eandry@mandriva.org> 4.13-7mdv2010.1
+ Revision: 506847
- BR help2man
- add upstream patch to fix crash when texi2dvi is used parallel

* Mon Sep 28 2009 Olivier Blin <oblin@mandriva.com> 4.13-6mdv2010.0
+ Revision: 450385
- add bootstrap flag not to depend on text in early bootstrap
  (from Arnaud Patard)

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 4.13-5mdv2010.0
+ Revision: 427347
- rebuild

* Thu Mar 19 2009 Andrey Borzenkov <arvidjaar@mandriva.org> 4.13-4mdv2009.1
+ Revision: 357607
- patch200: fix display of multibyte modelines

* Wed Feb 18 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.13-3mdv2009.1
+ Revision: 342520
- update dependency on 'lzma' to 'xz'
- use size_t for len (P109 from cvs, fixes bug where ie. default info index
  wouldn't be shown when compiled with -fstack-protector)

* Fri Dec 26 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.13-2mdv2009.1
+ Revision: 319330
- ditch INSTALL from docs as it's of no use for a binary package..
- remove explicit .lzma suffix from man pages
- ditch bzip2 dependency as we no longer use it for compression
- add support for new xz format which obsoletes old lzma format
- regenerate texinfo-*-test.patch

* Wed Dec 10 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 4.13-1mdv2009.1
+ Revision: 312385
- update to new version 4.13
- rediff patch 107
- fix mixture of tabs and spaces

* Fri Sep 05 2008 Thierry Vignaud <tv@mandriva.org> 4.12-1mdv2009.0
+ Revision: 281249
- adjust (and sort) file list for new man pages
- new release
- remove merged upstream lzma support patch
- new release (upstream now uses lzma)

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 4.11-3mdv2009.0
+ Revision: 225683
- rebuild

* Sat Jan 19 2008 Anssi Hannula <anssi@mandriva.org> 4.11-2mdv2008.1
+ Revision: 155146
- buildrequires tetex-latex for make check
- buildrequires tetex for make check
- require virtual texmf-data instead of tetex

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - do not package big ChangeLog
    - reenable test suite so that we can find out which BR is missing

* Tue Nov 13 2007 Thierry Vignaud <tv@mandriva.org> 4.11-1mdv2008.1
+ Revision: 108472
- temporary disable checks (only failed in iurt)

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - new version

* Sat Jul 14 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 4.9-1mdv2008.0
+ Revision: 52026
- spec file clean
- disable rpath
- new version

* Wed Jul 11 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.8-10mdv2008.0
+ Revision: 51129
- add requires on lzma for info-install

* Wed Jul 11 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.8-9mdv2008.0
+ Revision: 51125
- increase buffer size to make lzma match actually work without false positives (P4)
- improve matching on old lzma format (P4)
- disable lzma patch for now due to fugly errors screwing up /etc/info-dir
- fix typo in lzma patch (P4) that broke it
- fix detection of future lzma format in P4

* Sat Jun 09 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.8-8mdv2008.0
+ Revision: 37736
- fix matching of new lzma format (thx Lasse Collins)
- fix lzma patch where matching against old(current) format was broken
- add support for new(future) lzma format

* Thu Jun 07 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.8-7mdv2008.0
+ Revision: 36874
- add lzma support (P4)
- move build check to %%check
- cleanups

* Mon Apr 30 2007 Pixel <pixel@mandriva.com> 4.8-6mdv2008.0
+ Revision: 19546
- explicit file provide /sbin/install-info


* Mon Nov 13 2006 Thierry Vignaud <tvignaud@mandriva.com> 4.8-5mdv2007.0
+ Revision: 83619
- Import texinfo

* Mon Nov 13 2006 Thierry Vignaud <tvignaud@mandrakesoft.com> 4.8-5mdv2007.1
- patch 3: fix for security issue CVE-2006-4810

* Tue Sep 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 4.8-4mdv2007.0
- Rebuild

* Thu Jun 15 2006 David Walluck <walluck@mandriva.org> 4.8-3mdv2007.0
- Requires: tetex

* Fri Oct 07 2005 Thierry Vignaud <tvignaud@mandriva.com> 4.8-2mdk
- fix prereq (#17420)

* Thu Feb 10 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 4.8-1mdk
- new release
- kill patch 109 (merged upstream)

* Wed Dec 15 2004 Guillaume Rousse <guillomovitch@zarb.org> 4.7-3mdk
- make test robust against environment locales
- spec cleanup

* Fri Jul 30 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 4.7-2mdk
- patch 109: fix macros support in texinfo so that groff documentation works

* Fri Jul 02 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 4.7-1mdk
- Release: 4.7.
- Rebuilt Patch107.

